#
# Copyright (c) 2018, Oracle and/or its affiliates. All rights reserved.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License, version 2.0, as
# published by the Free Software Foundation.
#
# This program is also distributed with certain software (including
# but not limited to OpenSSL) that is licensed under separate terms,
# as designated in a particular file or component or in included license
# documentation.  The authors of MySQL hereby grant you an
# additional permission to link the program and your derivative works
# with the separately licensed software that they have included with
# MySQL.
#
# Without limiting anything contained in the foregoing, this file,
# which is part of MySQL Connector/C++, is also subject to the
# Universal FOSS Exception, version 1.0, a copy of which can be found at
# http://oss.oracle.com/licenses/universal-foss-exception.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License, version 2.0, for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA

%{?mysql_dir:    %global mysql_opt -DMYSQL_DIR=%{mysql_dir}}
%{!?commercial:  %global license_type GPLv2}
%{?commercial:   %global license_type Commercial}
%{?commercial:   %global product_suffix -commercial}
%{!?commercial:  %global product_suffix %{nil}}
%{!?_licensedir: %global license %doc}

%{?el6:%global __strip /opt/rh/devtoolset-7/root/usr/bin/strip}

%if 0%{?suse_version} == 1315
%global dist            .sles12
%endif

%if 0%{?suse_version} == 1500
%global dist            .sl15
%endif

Summary:        MySQL database connector for C++
Name:           mysql-connector-c++%{?product_suffix}
Version:        8.0.15
Release:        1%{?commercial:.1}%{?dist}
License:        %{license_type}
URL:            https://dev.mysql.com/doc/connector-cpp/en/
Source0:        https://dev.mysql.com/get/Downloads/Connector-C++/mysql-connector-c++%{?product_suffix}-%{version}-src.tar.gz
#BuildRequires:  boost-devel
BuildRequires:  cmake
%if 0%{?fedora} || 0%{?suse_version}
BuildRequires:  gcc
BuildRequires:  gcc-c++
%else
BuildRequires:  devtoolset-7-gcc
BuildRequires:  devtoolset-7-gcc-c++
%endif
%{!?mysql_dir:BuildRequires: mysql-devel}
%if 0%{?fedora} > 28
BuildRequires:  compat-openssl10-devel
%else
BuildRequires:  openssl-devel
%endif
%{?commercial:Obsoletes: mysql-connector-c++ < %{version}-%{release}}
%description
A C++ interface for communicating with MySQL servers.

%package        jdbc
Summary:        MySQL Driver for C++ which mimics the JDBC 4.0 API
%{?commercial:Obsoletes: mysql-connector-c++-jdbc < %{version}-%{release}}
Obsoletes:      libmysqlcppconn7 < %{version}-%{release}
Obsoletes:      libmysqlcppconn-devel < %{version}-%{release}
Provides:       libmysqlcppconn7 = %{version}-%{release}
Provides:       libmysqlcppconn-devel = %{version}-%{release}
%description    jdbc
This MySQL Driver for C++ mimics the JDBC 4.0 API.

%package        devel
Summary:        Development header files and libraries for MySQL C++ client applications
%if 0%{?commercial}
Requires:       mysql-connector-c++-commercial =  %{version}-%{release}
Requires:       mysql-connector-c++-commercial-jdbc =  %{version}-%{release}
Obsoletes:      mysql-connector-c++-devel < %{version}-%{release}
%else
Requires:       mysql-connector-c++ =  %{version}-%{release}
Requires:       mysql-connector-c++-jdbc =  %{version}-%{release}
%endif
%description    devel
This package contains the development header files and libraries necessary
to develop MySQL client applications in C++.

%if 0%{?with_tests:1} && 0%{?with_gtest:1}
%package        test
Summary:        Regression tests for MySQL Connector/C++
%if 0%{?commercial}
Requires:       mysql-connector-c++-commercial =  %{version}-%{release}
Requires:       mysql-connector-c++-commercial-jdbc =  %{version}-%{release}
Obsoletes:      mysql-connector-c++-test < %{version}-%{release}
%else
Requires:       mysql-connector-c++ =  %{version}-%{release}
Requires:       mysql-connector-c++-jdbc =  %{version}-%{release}
%endif
%description    test
This package contains the test files necessary to run regression
test suite for MySQL Connector/C++
%endif

%prep
%setup -q -n mysql-connector-c++%{product_suffix}-%{version}-src

%build
%{?rhel:export CC=/opt/rh/devtoolset-7/root/usr/bin/gcc}
%{?rhel:export CXX=/opt/rh/devtoolset-7/root/usr/bin/g++}

%if 0%{?with_tests:1} && 0%{?with_gtest:1}
TEST_OPTS="-DWITH_TESTS=1 -DWITH_GTEST=%{with_gtest}"
%else
TEST_OPTS=
%endif

mkdir build-dynamic && pushd build-dynamic
%if 0%{?fedora} || 0%{?rhel}
%cmake .. -DCMAKE_BUILD_TYPE=RelWithDebInfo -DWITH_JDBC=ON -DWITH_SSL=system %{?mysql_opt} \
    -DCMAKE_INSTALL_INCLUDEDIR=%{_includedir}/mysql-cppconn-8 \
    ${TEST_OPTS}
%else
cmake .. -DCMAKE_BUILD_TYPE=RelWithDebInfo -DWITH_JDBC=ON -DWITH_SSL=system %{?mysql_opt} \
    ${TEST_OPTS} \
    -DCMAKE_INSTALL_PREFIX="%_prefix" \
    -DCMAKE_INSTALL_INCLUDEDIR=%{_includedir}/mysql-cppconn-8 \
    -DCMAKE_C_FLAGS:STRING="%optflags" \
    -DCMAKE_CXX_FLAGS:STRING="%optflags"
%endif
make %{?_smp_mflags} VERBOSE=1
popd

mkdir build-static && pushd build-static
%if 0%{?fedora} || 0%{?rhel}
%cmake .. -DCMAKE_BUILD_TYPE=RelWithDebInfo -DWITH_JDBC=ON -DWITH_SSL=system %{?mysql_opt} \
  -DCMAKE_INSTALL_INCLUDEDIR=%{_includedir}/mysql-cppconn-8 \
  ${TEST_OPTS} \
  -DBUILD_STATIC=ON
%else
cmake .. -DCMAKE_BUILD_TYPE=RelWithDebInfo -DWITH_JDBC=ON -DWITH_SSL=system %{?mysql_opt} \
    ${TEST_OPTS} \
    -DBUILD_STATIC=ON \
    -DCMAKE_INSTALL_PREFIX="%_prefix" \
    -DCMAKE_INSTALL_INCLUDEDIR=%{_includedir}/mysql-cppconn-8 \
    -DCMAKE_C_FLAGS:STRING="%optflags" \
    -DCMAKE_CXX_FLAGS:STRING="%optflags"
%endif
make %{?_smp_mflags} VERBOSE=1
popd

%install
pushd build-dynamic
make DESTDIR=%{buildroot} install

%if 0%{?with_tests:1} && 0%{?with_gtest:1}
# Generating the test groups and run CMake again
# to process the generated TestGroups.cmake file
LD_LIBRARY_PATH=. ./run_unit_tests --generate_test_groups=TestGroups.cmake
%if 0%{?fedora} || 0%{?rhel}
%cmake ..
%else
cmake ..
%endif
# Move the test executable and test definition to private libdir
install -d -m0755 %{buildroot}%{_libdir}/mysql-cppconn-8/dynamic
mv CTestTestfile.cmake %{buildroot}%{_libdir}/mysql-cppconn-8/dynamic/
mv run_unit_tests      %{buildroot}%{_libdir}/mysql-cppconn-8/dynamic/
%endif
popd

pushd build-static
make DESTDIR=%{buildroot} install

%if 0%{?with_tests:1} && 0%{?with_gtest:1}
# Generating the test groups and run CMake again
# to process the generated TestGroups.cmake file
./run_unit_tests --generate_test_groups=TestGroups.cmake
%if 0%{?fedora} || 0%{?rhel}
%cmake ..
%else
cmake ..
%endif
# Move the test executable and test definition to private libdir
install -d -m0755 %{buildroot}%{_libdir}/mysql-cppconn-8/static
mv CTestTestfile.cmake %{buildroot}%{_libdir}/mysql-cppconn-8/static/
mv run_unit_tests      %{buildroot}%{_libdir}/mysql-cppconn-8/static/
%endif
popd

# Add compat dir and remove unwanted file
ln -s mysql-cppconn-8 %{buildroot}%{_includedir}/mysql-cppconn
rm %{buildroot}/usr/{INFO_SRC,INFO_BIN}

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%post jdbc -p /sbin/ldconfig
%postun jdbc -p /sbin/ldconfig

%files
%doc README.txt LICENSE.txt INFO_SRC build-dynamic/INFO_BIN
%{_libdir}/libmysqlcppconn8.so.1*

%files jdbc
%doc README.txt LICENSE.txt INFO_SRC build-dynamic/INFO_BIN
%{_libdir}/libmysqlcppconn.so.7*

%files devel
%doc README.txt LICENSE.txt INFO_SRC build-dynamic/INFO_BIN
%{_libdir}/libmysqlcppconn.so
%{_libdir}/libmysqlcppconn-static.a
%{_libdir}/libmysqlcppconn8.so
%{_libdir}/libmysqlcppconn8-static.a
%{_includedir}/mysql-cppconn
%dir %{_includedir}/mysql-cppconn-8
%{_includedir}/mysql-cppconn-8/mysqlx
%{_includedir}/mysql-cppconn-8/jdbc

%if 0%{?with_tests:1} && 0%{?with_gtest:1}
%files test
%dir %{_libdir}/mysql-cppconn-8
%dir %{_libdir}/mysql-cppconn-8/dynamic
%dir %{_libdir}/mysql-cppconn-8/static
%{_libdir}/mysql-cppconn-8/dynamic/run_unit_tests
%{_libdir}/mysql-cppconn-8/dynamic/CTestTestfile.cmake
%{_libdir}/mysql-cppconn-8/static/run_unit_tests
%{_libdir}/mysql-cppconn-8/static/CTestTestfile.cmake
%endif

%changelog
* Tue Nov 27 2018 Balasubramanian Kandasamy <balasubramanian.kandasamy@oracle.com> - 8.0.14-1
- Added INFO_BIN and INFO_SRC files

* Fri Aug 24 2018 Kent Boortz <kent.boortz@oracle.com> - 8.0.13-1
- Added "test" package

* Wed May 16 2018 Balasubramanian Kandasamy <balasubramanian.kandasamy@oracle.com> - 8.0.11-1
- Adapt to MySQL Connector C++ 8.0

* Tue Apr 05 2016 Kent Boortz <kent.boortz@oracle.com> - 2.0.1-1
- initial package
